* this code reproduces all the tables and tests reported in Spamann & Kloehn, "Justice is Less Blind ...", 45 J Legal Studies 255 (2016)
* plus additional robustness checks
* exception: the Boschloo test reported in table 2 is not available for Stata; see reference in II.1 below for how to do it

* required: datasets prof_nohindsight.dta and FJC_April2015_nopersonal.dta; adjust path in line 22 to appropriate location

* CONTENTS:
* I. Professor survey: table 1 & robustness
* II. Experiment results
** II.1 table 2
** II.2 comparison of effect sizes (classical) (cf. pp 271-2)
** II.3 Bayes factors (pp. 271-272)
*****a) Nationality
*****b) Nationality > precedent?
** II.4 robustness checks as reported in footnotes & additional
*****a) Drop-outs & exclusions (especially: iPad issues)
*****b) Confused judgment reasons (cf. footnote 13)
*****c) Confounders / covariate balance (cf. footnote 12) (code only -- the data are identifiable and hence cannot be shared)
* III. Time spent with materials (discussion pp. 272-3)

set more off
global path "C:\Users\hspamann\Dropbox\Experiment\Results" // adjust as necessary

**************************************
**************************************
**** I. Professor survey ****************
use $path/Profs/prof_nohindsight.dta, clear

**** table 1
table nationality_effect precedent_effect, row col // table 1, as printed in the paper
signrank precedent_e = nationality_e // Wilcoxon signed-rank test reported in table 1
disp 2*(1-normal(r(z))) // to get the more precise p-value reported in the paper

**** robustness (mentioned but not reported in the paper)
* 1) checking that basic message identical in both rounds of the survey, and for each order of questions and scale
table round precedent_first strong_first, c(mean precedent_effect mean nationality_effect) // mean precedent-effect > mean nationality_effect in all permutations
* 2) checking that there are no significant differences between the answers in both rounds
ranksum p*effect, by(round)
ranksum n*effect, by(round)
* 3) checking that table 1 & Wilcoxon test are not materially different between rounds
bys round: table nationality_effect precedent_effect, row col
by  round: signrank precedent_e = nationality_e


********************************************
********************************************
**** II. Experiment results ********************
use $path/US/FJC_April2015_nopersonal.dta, clear

******************
**** II.1. table 2
table nationality precedent, c(mean guilty sum guilty n guilty) col row // NB: order of precedent columns is opposite of paper's
/* Boschloo unconditional tests: can't be done in Stata but on http://www4.stat.ncsu.edu/~boos/exact/ or in R using the package "Exact" */
* Fisher's exact test:
tab nationality guilty, exact
tab precedent guilty, exact

************************
**** II.2. Comparison of effect sizes (classical)
* non-parametric
tab guilty nat if nat==precedent, exact // nat is 1 Croat 2 Serb, precedent is 1 Sainovic 2 Vasiljevic, so this test compares the cells where only one factor is favorable to defendant
* parametric
ttest guilty if nat==prec, by(nat) // this appears to be the test erroneously reported in the paper (p. 272) -- it should have been the Fisher test from 2 lines prior
reg guilty b2.nat#b1.precedent // logit doesn't work well because it drops the 7 Sainovic/Serb observations because they are all affirmed ...
test _b[1.nat#1.precedent]-_b[2.nat#2.precedent]==0

************************
**** II.3. Bayes factors

* inputs: cell counts
table nationality precedent, c(sum guilty n guilty) col row replace
local k = table1[1]
local n = table2[1]
local k_c = table1[2] // croat marginals
local n_c = table2[2]
local k_s = table1[3] // serb marginals
local n_s = table2[3]
drop if _n<6 // to ease comprehension, keep only the individual nationalityXprecedent cells, not the totals
gsort +nationality -precedent // sort from favorable (croatian, vasiljevic) to unfavorable (serbian, sainovic) for defendant
local k_00 = table1[1]
local k_10 = table1[3]
local k_01 = table1[2]
local k_11 = table1[4]
local n_00 = table2[1]
local n_10 = table2[3]
local n_01 = table2[2]
local n_11 = table2[4]

clear
set obs 1001
gen p_s = (_n-1)/1000	// conviction probability for Serb; that's what we will integrate over

**** a) Does nationality matter?
gen double integrand = p_s^(`k_s'-1)*(1-p_s)^(`n_s'-`k_s')*ibeta(`k_c'+1,`n_c'-`k_c'+1,p_s)
integ integrand p_s, generate(integral)
disp r(integral)*exp(lngamma(`n'+2)+lngamma(`k_c'+1)+lngamma(`n_c'-`k_c'+1)-lngamma(`k'+1)-lngamma(`n'-`k'+1)-lngamma(`n_c'+2))

**** b) Does nationality matter more than precedent?
gen double f_00=binomialp(`n_00',`k_00',p_s)
gen double fscaled_01=binomialp(`n_01',`k_01',p_s)/p_s
gen double fscaled_10=binomialp(`n_10',`k_10',p_s)/p_s
gen double fscaled_11=binomialp(`n_11',`k_11',p_s)/p_s

integ f_00 p_s, generate(integral_00)

replace		integrand = integral_00 * fscaled_01
integ 		integrand p_s, generate(integral) replace
replace 	integrand = integral * fscaled_10
integ		integrand p_s, generate(integral) replace
replace 	integrand = integral * fscaled_11
integ		integrand p_s
local L_H1=r(integral)

replace		integrand = integral_00 * fscaled_10
integ 		integrand p_s, generate(integral) replace
replace 	integrand = integral * fscaled_01
integ		integrand p_s, generate(integral) replace
replace 	integrand = integral * fscaled_11
integ		integrand p_s

disp `L_H1'/r(integral)

*********************
**** II.4. Robustness
use $path/US/FJC_April2015_nopersonal.dta, clear

*** a) Drop-outs & exclusions: frozen iPads and similar issues; prior knowledge of international criminal law (ICL)

* patterns: who dropped out when, and did they know ICL
sort time1 // time1 is when the participant clicked "start" on the iPad, which showed nothing before that
list time1-time3 guilty nat prec canceled time6 know
	/* Notes:
		1) Failures: earliest time somebody finished instructions (time3) but did NOT submit a judgment (= likely iPad failure) is 14:20:01. So start times before 14:20:01 should be clean participations. There are 27 such participations with verdicts.
		2) Other non-completions:
			a) one participant (Serb-Vasiljevic-NotGuilty-NoICLknowledge) cancelled instead of completing step 6 ("exit"): This person began at 14:18 (step 1) and went all the way to 15:03 (step 5).
			b) one participant (Croat-Vasiljevic-NotGuilty-NoICLknowledge) didn't hit "exit" button.
		3) ICL knowledge: three participants said they knew ICL. One of them started participation at 14:48:24 (i.e., iPad had crashed)
	*/

* testing for differential drop out rates (none detected)
tab nat prec if mi(guilty), exact

* various ways of handling incomplete participations incl. exclusions for prior knowledge of ICL -- results are practically the same regardless of how one does it
preserve
forvalues complete=0/1 {			// complete means: formally finished the experiment, i.e., hit the "exit" button and not the "cancel" button
	forvalues clean=0/1 {			// clean means: certainly did not progress past the instructions before receiving a second iPad
		forvalues novice=0/1 {		// novice means: did not answer "yes" to question whether knew any ICL
			keep if (1-mi(time6))>=`complete' & (time1<tc(14apr2015 14:20:01))>=`clean' & (knowICL!="yes")>=`novice'
			prtest guilty, by(nat)
			local z= 2*normal(r(z))
			tab nat guilty, exact
			local p = r(p_exact)
			tab prec guilty, exact
			matrix pvalues = (nullmat(pvalues) \ `complete',`clean',`novice', `z', `p', r(p_exact), r(N))
			restore, preserve
		}
	}
}
restore, not
matrix colnames pvalues = complete clean novice NATprop NATFET PRECFET N
mat list pvalues

* extreme scenario: what would have happened if all aborts had gone against our finding?
preserve
replace guilty=1 if mi(guilty) & nationality=="croatian":nationality
replace guilty=0 if mi(guilty) & nationality=="serbian":nationality
tab nat guilty, exact // now insignificant (p=0.76) ...
tab nat prec, sum(guilty) means obs // ... but still Serb (.62) more likely to be convicted than Croat (.55)
restore
drop if mi(guilty)

*** b) confusion as manifested in judgment reasons (correct or exclude)
gen guilty_corrected = guilty
replace guilty_corrected = 1 if regexm(judgmentreasons,"Facilitating the ability of death squads to accomplish their known mission is not a defense under the statute either.") ///
	| regexm(judgmentreasons,"Its legal premise was expressly rejected by the Sainovic panel") ///
	| regexm(judgmentreasons,"I would affirm the finding that the Defendant was guilty of aiding and abetting")
tab nat guilty_corrected, exact // still get p=0.018

gen dubious = judgmentreasons=="" | regexm(judgmentreasons,"Not sufficient time to form a judgment")
gen dubX = dubious + regexm(judgmentreasons,"the evidence adduced at trial does not support a finding that Horvat rendered practical assistance")
foreach outcome in guilty guilty_corrected { // the only combo that is problematic is dubX without other restrictions, which gives p=.1 or .16 for the raw and corrected measures, respectively
	foreach stringency in dubious dubX {
	tab `outcome' nat if !`stringency', exact
	tab `outcome' nat if !`stringency' & !mi(time6) & time1<tc(14apr2015 14:20:01), exact
	}
}

*** c) Confounders / Covariate balance (code only -- the data are identifiable and hence cannot be shared)
/*
foreach trait in knowICL prosecutor defense gender agegroup {
	disp ""
	disp "*** `trait' ***"
	foreach factor in nationality precedent {
		disp "* `trait' --> `factor'"
		if "`trait'"=="agegroup" ranksum `trait', by(`factor')
		else tab `factor' `trait', exact // Fisher exact test is appropriate because conditional on who is in the room, both margins actually are fixed (subject to some uncertainty around the edges arising from randomization circles)!
		}
	}
	
* result: only significant difference is gender-nationality: all 7 women had Horvat! Vukovic also had higher proportion of prosecutors (5 v 3), but insignificant
foreach controls in gender "gender prosecutor" {
foreach vce in ols robust bootstrap {
	reg guilty nationality `controls', vce(`vce')
}
}
*/

*****************************************
*****************************************
**** III. Time spent with materials *****

gen t_legal=t_statute+t_prec
foreach time in t_precedent t_statute t_legal t_total {
	ttest `time'												,  by(conflict)
	local p_l = r(p_l)
	local p = r(p)
	local diff = r(mu_2)-r(mu_1)
	local t = -r(t)
	ttest `time' if !mi(time6) & time1<tc(14apr2015 14:20:01)	,  by(conflict)
	matrix time_pvalues = (nullmat(time_pvalues) \ `diff',`t',`p_l',`p',`=r(mu_2)-r(mu_1)',`=-r(t)',r(p_l),r(p))
	}
matrix colnames time_pvalues = full_excess full_t full_ones full_twos clean_excess clean_t clean_ones clean_twos
matrix rownames time_pvalues = t_precedent t_statute t_legal t_total
mat list time_pvalues
